# Half-Life: Source - Issues

Here's a list of things that we'd fix in Half-Life: Source (and Deathmatch), given the opportunity.

The game is in a messy state. The potential for rebasing Half-Life on top of Source is incredible - but this attempt is sadly not good enough.

# 1/2 BIG IMPROVEMENTS TO THE GAME

## Bug: Entities double spawning in multiplayer

All entities double spawn in multiplayer. Supposedly a gamerule class method needs to be stubbed out because it's running spawn code twice? We don't have the source code to HL:S, so we have no idea.

## Inconsistency: The wrong sound, everywhere

Sounds from Half-Life 2 clash with Half-Life. Doors during the train ride should not sound like a door handle is being pulled. The footsteps are all from Half-Life 2 as well and clash with the lower sampling rate sounds from Half-Life.

## Inconsistency: HD Pack is stolen from GameBanana

Due to a lack of sources of the Gearbox HD Pack, Alfred decided to push up a fan edit and port of the HD Pack that was linked to him on GitHub. He removed the custom world textures, but the models also contain edits.

## Inconsistency: HD Pack needs to be off by default.

An option to turn on the HD pack was introduced in the 2013 update with the HD pack being the default. This was not the intended way to play Half-Life.

## Bug: PVS optimization done for Episode 1 breaking the Tentacle

There was an optimization done to the PVS during Episode 1's development that makes it so only 1 of the Tentacles can actually harm the player.

## Bug: Apache hitbox.

The Apache's hitbox doesn't detect any of the unique hitboxes in the model. To boot, the hitbox is now a tiny square in the center of the Apache.

## Bug: Barnacle's tongue does not calculate distance to floor correctly.

This may be related to the EP1 PVS optimization.

## Bug: Sitting Scientists can float.

Ditto

## Bug: Apache is floating in the tram ride.

Ditto

## Bug: Leak in C2A5C

There's a leak in C2A5C that causes the 3D Skybox to render inconsistently.

Alfred attempted to fix this by adding the ignorez command to the VMTs for all of the skyboxes. That will need to be fixed too as it becomes a duplicate entry in certain skybox VMTs.

# 2/2 EVERYTHING ELSE. STILL IMPORTANT THOUGH!

## Bug: Yaw Speed is TOO fast on all HL monsters.

For whatever reason, there's some major difference between GoldSource's SetYawSpeed and Source's MaxYawSpeed. This results in all monsters in Half-Life: Source rotating too fast. This is why the Scientists starts spinning when freaked out.

## Bug: Shotgun's double blast plays the single blast sound.

This is due to the sound being defined in the code... 2 times? Single Blast sound call ultimately over takes the Double Blast sound call.

## Bug: Egon has a secondary attack.

This is not the case in HL. Post-1.1 HL does have a bug where it will play a random idle if you press the secondary attack, that too needs fixed.

## Bug: Some weapons have no muzzleflash in third person.

Only the MP5/9mmAR has a muzzleflash!

## Bug: RPG does not use firing animation in third person.

See title.

## Bug: There's no concept of p_models.

Half-Life 1 used both w_models and p_models for the weapons in the enviroment. w_models were intended for laying around in the world and p_models were intended to be held by the players. Source uses w_models for both of these, which results in an inconsistency with Half-Life 1.

This is the most noticable with the Snark. The world is supposed to have a Snark Nest and the player is supposed to hold a Snark. In the 2013 Update, the Snark Nest was just replaced with the Snark. Prior to the 2013 update the Snark Nest would use the player model's skeleton.

This would require an edit of BaseCombatWeapon. Scripts would also need to be updated to include the field "worldmodel" and the "playermodel" field would need to be updated to use the p_model version of the weapons. Both model resources would need to be ported back to Half-Life: Source.

## Quality of Life/Bug: Player Models are hardcoded.

In Half-Life 1, you could install new player models at will. In Half-Life Deathmatch: Source, there's a hardcoded list of players allowed to be selected.

GameUI appears to be okay with new player models being added, so this is a check with-in game logic.

## Inconsistency: Recon player model is missing.

The Recon player model was not provided with Half-Life Deathmatch: Source.

## Bug: 357 Sight

HLDMS does not enable the 357 Sight bodygroup when in MP. Half-Life: Source can also sometimes have the sight behavior randomly kick in.

## Bug: You cannot turn off footsteps.

The multiplayer Create Server menu has the option to disable footsteps. That's completely ignored. Unacceptable.

## Bug: You drop a weapon like HL2DM and not a weapon box like in HL1.

In HLDMS, you drop weapons like in HL2DM instead of a weapon box. Half-Life 1 drops a weapon box.

## Bug: Wrong hit sounds.

Go into rapidcore.bsp and hit the metal pillar in the middle of the room with the glass floor and MP5/9mmAR pickup. It makes flesh impact sounds, but only to the local player. Is the material type networked properly?

## Bug: Pickup icons for HEV Batteries and Medkits do not render in widescreen on the HUD.

This works in 4:3, but widescreen this pickup icons render off screen.

## Bug: You can open up the scoreboard in Half-Life: Source

Pressing tab will result in a white rectangle rendering on screen. This is a broken scoreboard.

## Bug: HUD colors are wrong for ammo in HLDMS

Weapon selection ammo colors are wrong in Half-Life Deathmatch: Source. HLDMS uses ClientScheme from Counter-Strike: Source instead of Half-Life: Source. This results in various colors being incorrect. Select colors will need to be ported over for Deathmatch related colors.

## Bug: Auto Aim crosshair behavior is active, but no auto aim?

When you aim at monsters, the crosshair will go red. This is a behavior of HL1's auto aim and doesn't happen when auto aim is off. It doesn't appear that Auto Aim exists or works with-in Half-Life: Source.

## Inconsistency: Gibs just shoot out physic props.

Cool demostration of the tech, but it get rid of all of the quirks and Easter Eggs of the original gibbing code.

Additionally, it just makes the generic physic sound.

## Bug: Credits button on rapidcore.bsp does not work

Assuming that is a mistake. The button is still there, but the author credits no longer show up.

## Bug: Buttons don't light up at all in multiplayer

Buttons are supposed to change texture. Probably related to the double spawning of entities?

## Bug: Doors can close on snarks

... and get stuck. They will eventually die.

## Bug: Gauss impacts

Shooting wood materials with the Gauss will produce incorrectly rendered blue particles.

## Inconsistency: `drop` command does not exist in multiplayer.

In Half-Life, you could issue `drop` in console (or bind it) to drop the currently held weapon. This is missing here.

## Quality of Life: Server password is not saved?

Whenever a server gets started, the Create Server menu has defaults set - no setting is ever saved.

## Inconsistency/Fluff: Restore Retail HL1 View Bob and Weapon Bob

It is possible to restore the original view bob and weapon bob seen in the disc release of HL.

## Fluff: More cubemaps instead of spherical environment maps

One massively missed opportunity was to not use cubemaps for the majority of environment mapping in Half-Life: Source.

## Fluff: The chrome effect is not accurate at all

[FreeHL/Nuclide](https://code.idtech.space/vera/nuclide/src/branch/master/platform/base_glsl.pk3dir/glsl/defaultskin.glsl) use a .glsl that mimics the effect accurately. That'd have to be converted into a Source Engine shader. (HLSL?)

## Bug: Gus' model has broken UVs.

Textures aren't properly aligned on him.

![Gus](gus-hls.jpg)

## Fluff: Steam Artwork is non-existant

For both Half-Life: Source and Half-Life Deathmatch: Source.

## Fluff: Feedback on the map conversions

- Boot_Camp: What's with all the added crates? And the barricaded door? This wouldn't pass [Wolpaw's Crate Test.](http://www.oldmanmurray.com/features/39.html)
- Bounce: Is fine.
- Crossfire: Is fine.
- Datacore: Is good.
- Frenzy: Has an exploit. You can jump up with the Gauss Rifle onto a penetrable ceiling - metal grate type surface on which they can shoot everyone with an advantage.
- Lambda_Bunker: Is good.
- Rapidcore: The lighting is atrocious.
- Snark_Pit: Is good.
- Stalkyard: Is good.
- Subtransit: Is fine.
- Undertow: Is fine.

Where is gasworks? This map was available with Half-Life 1.

Port over the Further Data content? Dario made some really great maps for HL post-release. Where are they???

## Fluff: GoldSrc compatibility layer

Make HL:S load GoldSrc game-logic through a shim. Give the client the ability to intercept the packets that the Source Engine doesn't natively implement. Perhaps unfeasible. Source would also need to support the GoldSrc file formats for this. Probably will never happen, but would make everyones dreams come true.